@@ -1,7 +1,7 @@
 package Data::Clean;
 
-our $DATE = '2019-08-08'; # DATE
-our $VERSION = '0.503'; # VERSION
+our $DATE = '2019-09-01'; # DATE
+our $VERSION = '0.504'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,6 +49,11 @@ sub command_one_or_zero {
     return "{{var}} = {{var}} ? 1:0; \$ref = ''";
 }
 
+sub command_deref_scalar_one_or_zero {
+    my ($self, $cd, $args) = @_;
+    return "{{var}} = \${ {{var}} } ? 1:0; \$ref = ''";
+}
+
 sub command_deref_scalar {
     my ($self, $cd, $args) = @_;
     return '{{var}} = ${ {{var}} }; $ref = ref({{var}})';
@@ -287,7 +292,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.503 of Data::Clean (from Perl distribution Data-Clean), released on 2019-08-08.
+This document describes version 0.504 of Data::Clean (from Perl distribution Data-Clean), released on 2019-09-01.
 
 =head1 SYNOPSIS
 
@@ -401,6 +406,10 @@ as the replacement.
 
 This will perform C<< $val ? 1:0 >>.
 
+=item * ['deref_scalar_one_or_zero']
+
+This will perform C<< ${$val} ? 1:0 >>.
+
 =item * ['deref_scalar']
 
 This will replace a scalar reference like \1 with 1.
@@ -503,7 +512,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
